# coinmarketcap-api

[![Greenkeeper badge](https://badges.greenkeeper.io/tiaanduplessis/coinmarketcap-api.svg)](https://greenkeeper.io/) [![npm package version](https://img.shields.io/npm/v/coinmarketcap-api.svg?style=flat-square)](https://npmjs.org/package/coinmarketcap-api)
[![npm downloads](https://img.shields.io/npm/dm/coinmarketcap-api.svg?style=flat-square)](https://npmjs.org/package/coinmarketcap-api) [![Standard JS linter](https://img.shields.io/badge/code%20style-standard-brightgreen.svg?style=flat-square)](https://github.com/feross/standard) [![Codecov](https://codecov.io/gh/tiaanduplessis/coinmarketcap-api/branch/master/graph/badge.svg?style=flat-square)](https://codecov.io/gh/tiaanduplessis/coinmarketcap-api)  [![travis ci build status](https://img.shields.io/travis/tiaanduplessis/coinmarketcap-api.svg?style=flat-square)](https://travis-ci.org/tiaanduplessis/coinmarketcap-api)  [![project license](https://img.shields.io/npm/l/coinmarketcap-api.svg?style=flat-square)](https://github.com/tiaanduplessis/coinmarketcap-api/blob/master/LICENSE) [![make a pull request](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)  

> CoinMarketCap API wrapper for node

## Table of Contents

-   [Install](#install)
-   [Usage](#usage)
-   [API](#api)
-   [Contribute](#contribute)
-   [License](#license)

## Install

```sh
$ npm install coinmarketcap-api
# OR
$ yarn add coinmarketcap-api
```

## Usage

```js
const CoinMarketCap = require('coinmarketcap-api')

const client = new CoinMarketCap()

client.getTicker().then(console.log).catch(console.error)
client.getGlobal().then(console.log).catch(console.error)
```

Check out the [CoinMarketCap API documentation](https://coinmarketcap.com/api/) for more information!

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

#### Table of Contents

-   [constructor](#constructor)
-   [getListings](#getlistings)
-   [getTicker](#getticker)
-   [getGlobal](#getglobal)

### constructor

**Parameters**

-   `Options` **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)?** Options for the CoinMarketCap instance (optional, default `{}`)
    -   `Options.version`   (optional, default `'v2'`)
    -   `Options.fetcher`   (optional, default `fetch`)
    -   `Options.config`   (optional, default `{}`)

### getListings

Get all active cryptocurrency listings

**Examples**

```javascript
const client = new CoinMarketCap()
client.getListings().then(console.log).catch(console.error)
```

### getTicker

Get ticker information.
Start and limit options can only be used when currency or ID is not given.
Currency and ID cannot be passed in at the same time.

**Parameters**

-   `args`   (optional, default `{}`)
-   `options` **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)?** Options for the request:
    -   `options.start` **Int?** Return results from rank start + 1 and above
    -   `options.limit` **Int?** Only returns limit number of results
    -   `options.convert` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** Return price, 24h volume, and market cap in terms of another currency
    -   `options.currency` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** Return only specific currency
    -   `options.id` **Int?** Return only specific currency associated with its ID from listings

**Examples**

```javascript
const client = new CoinMarketCap()
client.getTicker({limit: 3}).then(console.log).catch(console.error)
client.getTicker({convert: 'EUR'}).then(console.log).catch(console.error)
client.getTicker({start: 0, limit: 5}).then(console.log).catch(console.error)
client.getTicker({currency: 'BTC'}).then(console.log).catch(console.error)
client.getTicker({convert: 'JPY', id: 2}).then(console.log).catch(console.error)
```

### getGlobal

Get global information

**Parameters**

-   `convert`  
-   `options` **([Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object) \| [String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String))?** Options for the request
    -   `options.convert` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** Return price, 24h volume, and market cap in terms of another currency

**Examples**

```javascript
const client = new CoinMarketCap()
client.getGlobal('GBP').then(console.log).catch(console.error)
client.getGlobal({convert: 'GBP'}).then(console.log).catch(console.error)
```

## Contributing

Contributions are welcome!

1.  Fork it.
2.  Create your feature branch: `git checkout -b my-new-feature`
3.  Commit your changes: `git commit -am 'Add some feature'`
4.  Push to the branch: `git push origin my-new-feature`
5.  Submit a pull request :D

Or open up [a issue](https://github.com/tiaanduplessis/coinmarketcap-api/issues).

## License

Licensed under the MIT License.
